-- The top level Test Bench

library ieee;
use ieee.std_logic_1164.all;

entity TestBench is                                  -- No ports needed in a
end TestBench;                                       -- testbench

architecture TestBench_1 of TestBench is             -- Declares the lower-level

   component ShiftAndCompare                         -- component and its port
      port ( Clk, Rst, Load: in std_ulogic;
             Init: in std_ulogic_vector ( 7 downto 0 );
             Test: in std_ulogic_vector ( 7 downto 0 );
             Limit: out std_ulogic );
   end component;

   signal Clk, Rst, Load: std_ulogic;                -- Introduces top-level signals
   signal Init: std_ulogic_vector ( 7 downto 0 );        -- to use when testing the
   signal Test: std_ulogic_vector ( 7 downto 0 );        -- lower-level circuit
   signal Limit: std_ulogic;

begin

   UUT: ShiftAndCompare                              -- Creates an istance of the
        port map ( Clk, Rst, Load,                   -- lower-level circuit
                   Init, Test, Limit );              -- (the Unit Under Test)

   clock: process                                    -- This process sets up a
      variable clktmp: std_ulogic := '0';            -- background clock of 100 ns
   begin                                             -- period
      clktmp := not clktmp;
      Clk <= clktmp;
      wait for 50 ns;
   end process;

   stimulus: process                                 -- This process applies
   begin                                             -- stimuls to the design
      Rst <= '0';                                    -- inputs, then waits for some
      Load <= '1';                                   -- amount of time so wa can
      Init <= "00001111";                            -- observe the results during
      Test <= "11110000";                            -- simulation
      wait for 100 ns;
      Load <= '0';
      wait for 600 ns;
   end process;

end TestBench_1;
